BCryptAesGcm class

Thin FFI binding to Windows CNG AES-256-GCM. Use tryLoad; null = unavailable.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decrypt(Uint8List key, Uint8List data) Uint8List
Decrypt nonce(12) | ciphertext | tag(16); throws on auth failure.
encrypt(Uint8List key, Uint8List plaintext) Uint8List
Encrypt: returns nonce(12) | ciphertext | tag(16).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

tryLoad() BCryptAesGcm?