FilenCache class

Constructors

FilenCache({DateTime clock()?})

Properties

fileCache Map<String, CacheEntry>
final
folderCache Map<String, CacheEntry>
final
hashCode int
The hash code for this object.
no setterinherited
pathCache Map<String, Map<String, dynamic>>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearParentCache(String itemUuid, String itemType, FilenApi api, FilenCrypto crypto, List<String> masterKeys) Future<void>
clearPathCache() → void
invalidate(String folderUuid) → void
listFolderFiles(String uuid, {bool detailed = false, required FilenApi api, required FilenCrypto crypto, required List<String> masterKeys}) Future<List<Map<String, dynamic>>>
List files in folder uuid, using cache when available.
listFoldersAsync(String uuid, {bool detailed = false, required FilenApi api, required FilenCrypto crypto, required List<String> masterKeys}) Future<List<Map<String, dynamic>>>
List subfolders of uuid, using cache when available.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

cacheDuration → const Duration