InMemoryConfigStorage class

In-memory credential storage for unit tests.

Implemented types

Constructors

InMemoryConfigStorage()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearCredentials() Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readCredentials() Future<Map<String, dynamic>?>
override
saveCredentials(Map<String, dynamic> data) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited