crypto library
Cryptographic primitives for the Filen protocol.
Filen uses AES-256-GCM for both metadata and file chunk encryption, PBKDF2-HMAC-SHA512 for key derivation (200,000 iterations for auth), and HMAC-SHA256 for filename hashing.
Cryptographic primitives for the Filen protocol.
Filen uses AES-256-GCM for both metadata and file chunk encryption, PBKDF2-HMAC-SHA512 for key derivation (200,000 iterations for auth), and HMAC-SHA256 for filename hashing.