FilenCrypto class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decodeUniversalKey(String k)
→ Uint8List
-
-
decryptData(Uint8List data, Uint8List key)
→ Future<Uint8List>
-
-
decryptMetadata002(String m, String key)
→ Future<String>
-
-
deriveKeys(String password, int version, String salt)
→ Future<Map<String, String>>
-
-
encryptData(Uint8List data, Uint8List key)
→ Future<Uint8List>
-
-
encryptMetadata002(String text, String key)
→ Future<String>
-
-
generateHMACKey(List<String> masterKeys, String email)
→ Future<String>
-
-
hashFile(File file)
→ Future<String>
-
-
hashFileName(String name, List<String> masterKeys, String email)
→ Future<String>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
pbkdf2(List<int> password, List<int> salt, int iterations, int length)
→ Uint8List
-
-
randomBytes(int length)
→ Uint8List
-
-
randomString(int length)
→ String
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
tryDecrypt(String s, List<String> masterKeys)
→ Future<String>
-
Try decrypting with all available master keys (newest first).
-
uuid()
→ String
-