FilenDrive class

Constructors

FilenDrive({required FilenApi api, required FilenCrypto crypto, required FilenCache cache})

Properties

api FilenApi
final
baseFolderUUID String
getter/setter pair
cache FilenCache
final
crypto FilenCrypto
final
email String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
masterKeys List<String>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkFileExists(String parentUuid, String name) Future<bool>
createDirectory(String name, String parent, {String? creationTime, String? modificationTime}) Future<void>
createFolderRecursive(String path, {String? creationTime, String? modificationTime}) Future<Map<String, dynamic>>
deletePermanently(String uuid, String type) Future<void>
fetchAndParseTree(String rootUuid) Future<Map<String, List<Map<String, dynamic>>>>
findFiles(String startPath, String pattern, {int maxDepth = -1}) Future<List<Map<String, dynamic>>>
getFileMetadata(String uuid) Future<Map<String, dynamic>>
getFlatFolderTree(String folderUuid) Future<Map<String, dynamic>>
getFolderMetadata(String uuid) Future<Map<String, dynamic>>
getTrashContent() Future<List<Map<String, dynamic>>>
moveItem(String uuid, String destUuid, String type) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printTree(String path, void printLine(String), {int maxDepth = 3}) Future<void>
renameItem(String uuid, String newName, String type) Future<void>
resolveOrCreateFolder(String path) Future<Map<String, dynamic>>
resolvePath(String path) Future<Map<String, dynamic>>
restoreItem(String uuid, String type) Future<void>
toString() String
A string representation of this object.
inherited
trashItem(String uuid, String type) Future<void>
verifyUploadMetadata(String fileUuid, File originalFile) Future<bool>
Verify uploaded file using metadata hash (no download needed).

Operators

operator ==(Object other) bool
The equality operator.
inherited