FilenPaths extension

on

Methods

downloadFromPath(String remotePath, {String? localDestination}) Future<Map<String, dynamic>>

Available on FilenClient, provided by the FilenPaths extension

Download a file by remote path to a local destination.
listPath(String remotePath) Future<Map<String, List<Map<String, dynamic>>>>

Available on FilenClient, provided by the FilenPaths extension

List contents of a folder by path.
moveByPath(String sourcePath, String destPath) Future<void>

Available on FilenClient, provided by the FilenPaths extension

Move a file or folder by path.
renameByPath(String remotePath, String newName) Future<void>

Available on FilenClient, provided by the FilenPaths extension

Rename a file or folder by path.
trashByPath(String remotePath) Future<void>

Available on FilenClient, provided by the FilenPaths extension

Delete a file or folder by path (move to trash).
uploadFileBytes(Uint8List bytes, String remotePath, {String? mimeType}) Future<Map<String, String>>

Available on FilenClient, provided by the FilenPaths extension

Upload raw bytes as a file to a remote path.
uploadToPath(File localFile, String remotePath, {bool preserveTimestamps = false}) Future<Map<String, String>>

Available on FilenClient, provided by the FilenPaths extension

Upload a local file to a remote path.