FilenUpload class

Constructors

FilenUpload({required FilenApi api, required FilenCrypto crypto, required FilenCache cache, required FilenDrive drive, MemoryGate? memoryGate})

Properties

api FilenApi
final
cache FilenCache
final
crypto FilenCrypto
final
drive FilenDrive
final
email String
no setter
hashCode int
The hash code for this object.
no setterinherited
masterKeys List<String>
no setter
memoryGate MemoryGate
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
upload(List<String> sources, String targetPath, {required bool recursive, required String onConflict, required bool preserveTimestamps, required List<String> include, required List<String> exclude, required String batchId, Map<String, dynamic>? initialBatchState, required Future<void> saveStateCallback(Map<String, dynamic>), dynamic onFileProgress(String filename, int current, int total, int bytesUploaded, int totalBytes)?, int maxWorkers = kDefaultFileConcurrency}) Future<void>
Batch upload with resume, conflict handling, and progress tracking.
uploadBytes(Uint8List data, String fileName, String parentUuid, {int maxConcurrentChunks = kDefaultUploadConcurrency, dynamic onProgress(int bytesUploaded, int totalBytes)?}) Future<void>
Upload raw bytes from memory (needed for Web platform where File I/O is not available).
uploadFile(File file, String parent, {String? creationTime, String? modificationTime}) Future<void>
Simple single-file upload (non-chunked, for small files / WebDAV).
uploadFileChunked(File file, String parent, {String? fileUuid, String? creationTime, String? modificationTime, String? resumeUploadKey, int resumeFromChunk = 0, Set<int>? completedChunks, String? fileKey, int maxConcurrentChunks = kDefaultUploadConcurrency, ChunkSemaphore? globalChunkSlots, dynamic onProgress(int current, int total, int bytesUploaded, int totalBytes)?, dynamic onUploadStart(String uuid, String uploadKey, String fileKey)?, void onChunksCompleted(Set<int> completed)?}) Future<Map<String, String>>

Operators

operator ==(Object other) bool
The equality operator.
inherited