DigestSink class

Helper class to capture hash results from chunked hash computation.

Implemented types

Constructors

DigestSink()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value ↔ Digest?
getter/setter pair

Methods

add(Digest data) → void
Adds data to the sink.
override
close() → void
Closes the sink.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited