FilenDirectory class

Implemented types

Constructors

FilenDirectory({required FilenClient client, required String path, required FilenFileSystem fs})

Properties

absolute → Directory
A FileSystemEntity whose path is the absolute path of path.
no setter
basename String
Gets the part of this entity's path after the last separator.
no setter
client FilenClient
final
dirname String
Gets the part of this entity's path before the last separator.
no setter
fileSystem → FileSystem
Returns the file system responsible for this entity.
no setter
fs FilenFileSystem
final
hashCode int
The hash code for this object.
no setterinherited
isAbsolute bool
Whether this object's path is absolute.
no setteroverride
parent → Directory
The parent directory of this entity.
no setter
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uri Uri
A Uri representing the file system entity's location.
no setteroverride

Methods

childDirectory(String basename) → Directory
Returns a reference to a Directory that exists as a child of this directory and has the specified basename.
childFile(String basename) → File
Returns a reference to a File that exists as a child of this directory and has the specified basename.
Returns a reference to a Link that exists as a child of this directory and has the specified basename.
create({bool recursive = false}) Future<Directory>
Creates the directory if it doesn't exist.
createSync({bool recursive = false}) → void
Synchronously creates the directory if it doesn't exist.
override
createTemp([String? prefix]) Future<Directory>
Creates a temporary directory in this directory.
createTempSync([String? prefix]) → Directory
Synchronously creates a temporary directory in this directory.
delete({bool recursive = false}) Future<FileSystemEntity>
Deletes this FileSystemEntity.
deleteSync({bool recursive = false}) → void
Synchronously deletes this FileSystemEntity.
override
exists() Future<bool>
Checks whether the file system entity with this path exists.
override
existsSync() bool
Synchronously checks whether the file system entity with this path exists.
override
list({bool recursive = false, bool followLinks = true}) Stream<FileSystemEntity>
Lists the sub-directories and files of this Directory.
listSync({bool recursive = false, bool followLinks = true}) List<FileSystemEntity>
Lists the sub-directories and files of this Directory. Optionally recurses into sub-directories.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rename(String newPath) Future<Directory>
Renames this file system entity.
renameSync(String newPath) → Directory
Synchronously renames this file system entity.
Resolves the path of a file system object relative to the current working directory.
override
resolveSymbolicLinksSync() String
Resolves the path of a file system object relative to the current working directory.
override
setStat(FileStat stat) Future<void>
stat() Future<FileStat>
Calls the operating system's stat() function on path.
override
statSync() FileStat
Synchronously calls the operating system's stat() function on path.
override
toString() String
A string representation of this object.
inherited
watch({int events = FileSystemEvent.all, bool recursive = false}) Stream<FileSystemEvent>
Start watching the FileSystemEntity for changes.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited