childDirectory method

  1. @override
Directory childDirectory(
  1. String basename
)

Returns a reference to a Directory that exists as a child of this directory and has the specified basename.

Implementation

@override
Directory childDirectory(String basename) =>
    fs.directory(p.join(path, basename));