childFile method

  1. @override
File childFile(
  1. String basename
)

Returns a reference to a File that exists as a child of this directory and has the specified basename.

Implementation

@override
File childFile(String basename) => fs.file(p.join(path, basename));