childLink method

  1. @override
Link childLink(
  1. String basename
)

Returns a reference to a Link that exists as a child of this directory and has the specified basename.

Implementation

@override
Link childLink(String basename) => fs.link(p.join(path, basename));