setLastModifiedSync method
Synchronously modifies the time the file was last modified.
If the attributes cannot be set, throws a FileSystemException.
Implementation
@override
void setLastModifiedSync(DateTime time) =>
throw UnimplementedError('Sync operations not supported');