FilenAuth class
Constructors
- FilenAuth({required FilenApi api, required FilenCrypto crypto})
Properties
- api → FilenApi
-
final
- crypto → FilenCrypto
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fetchBaseFolderUUID(
) → Future< String> -
getAuthInfo(
String email) → Future< Map< String, dynamic> > -
login(
String email, String password, {String twoFactorCode = "XXXXXX"}) → Future< Map< String, dynamic> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited