ConfigService class
Constructors
- ConfigService({required String configPath, ConfigStorage? storage})
Properties
- batchStateDir ↔ String
-
latefinal
- configDir ↔ String
-
latefinal
- credentialsFile ↔ String
-
latefinal
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storage → ConfigStorage
-
The active credential storage backend (FileConfigStorage by default).
no setter
- webdavPidFile ↔ String
-
latefinal
Methods
-
clearCredentials(
) → Future< void> -
clearWebdavPid(
) → Future< void> -
deleteBatchState(
String batchId) → Future< void> -
generateBatchId(
String operationType, List< String> sources, String target) → String -
getBatchStateFilePath(
String batchId) → String -
loadBatchState(
String batchId) → Future< Map< String, dynamic> ?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readCredentials(
) → Future< Map< String, dynamic> ?> -
readWebdavPid(
) → Future< int?> -
saveBatchState(
String batchId, Map< String, dynamic> state) → Future<void> -
saveCredentials(
Map< String, dynamic> data) → Future<void> -
saveWebdavPid(
int pid) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited