FilenDownload class

Constructors

FilenDownload({required FilenApi api, required FilenCrypto crypto, required FilenCache cache, required FilenDrive drive})

Properties

api FilenApi
final
cache FilenCache
final
crypto FilenCrypto
final
drive FilenDrive
final
hashCode int
The hash code for this object.
no setterinherited
masterKeys List<String>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

downloadFile(String uuid, {String? savePath, int maxConcurrentChunks = kDefaultDownloadConcurrency, ChunkSemaphore? globalChunkSlots, dynamic onProgress(int bytesDownloaded, int totalBytes)?}) Future<Map<String, dynamic>>
Download a single file by UUID.
downloadFileBytes(String uuid, {int maxConcurrentChunks = kDefaultDownloadConcurrency, dynamic onProgress(int bytesDownloaded, int totalBytes)?}) Future<Uint8List>
Download file content as bytes (no disk I/O — needed for Web platform).
downloadFileRange(String uuid, {int? rangeStart, int? rangeEnd}) Future<Uint8List>
Download file with range support.
downloadPath(String remotePath, {String? localDestination, required bool recursive, required String onConflict, required bool preserveTimestamps, required List<String> include, required List<String> exclude, required String batchId, Map<String, dynamic>? initialBatchState, required Future<void> saveStateCallback(Map<String, dynamic>), int maxWorkers = kDefaultFileConcurrency}) Future<void>
Batch download by path with recursive support and resume.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited