FilenClient class
- Available extensions
Constructors
- FilenClient({required ConfigService config, Client? httpClient})
Properties
- api → FilenApi
-
final
- apiKey ↔ String?
-
getter/setter pair
- auth ↔ FilenAuth
-
latefinal
- baseFolderUUID ↔ String
-
getter/setter pair
- cache → FilenCache
-
final
- config → ConfigService
-
final
- crypto → FilenCrypto
-
final
- debugMode ↔ bool
-
getter/setter pair
- downloader ↔ FilenDownload
-
latefinal
- drive ↔ FilenDrive
-
latefinal
- email → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
masterKeys
↔ List<
String> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uploader ↔ FilenUpload
-
latefinal
Methods
-
checkFileExists(
String parentUuid, String name) → Future< bool> -
createFolderRecursive(
String path, {String? creationTime, String? modificationTime}) → Future< Map< String, dynamic> > -
deletePermanently(
String uuid, String type) → Future< void> -
downloadFile(
String uuid, {String? savePath, int maxConcurrentChunks = kDefaultDownloadConcurrency, dynamic onProgress(int, int)?}) → Future< Map< String, dynamic> > -
downloadFileBytes(
String uuid, {int maxConcurrentChunks = kDefaultDownloadConcurrency, dynamic onProgress(int, int)?}) → Future< Uint8List> -
downloadFromPath(
String remotePath, {String? localDestination}) → Future< Map< String, dynamic> > -
Available on FilenClient, provided by the FilenPaths extension
Download a file by remote path to a local destination. -
downloadPath(
String remotePath, {String? localDestination, required bool recursive, required String onConflict, required bool preserveTimestamps, required List< String> include, required List<String> exclude, required String batchId, Map<String, dynamic> ? initialBatchState, required Future<void> saveStateCallback(Map<String, dynamic> ), int maxWorkers = kDefaultFileConcurrency}) → Future<void> -
fetchBaseFolderUUID(
) → Future< String> -
findFiles(
String startPath, String pattern, {int maxDepth = -1}) → Future< List< Map< >String, dynamic> > -
getFileMetadata(
String uuid) → Future< Map< String, dynamic> > -
getFolderMetadata(
String uuid) → Future< Map< String, dynamic> > -
getTrashContent(
) → Future< List< Map< >String, dynamic> > -
listFolderFiles(
String uuid, {bool detailed = false}) → Future< List< Map< >String, dynamic> > -
listFoldersAsync(
String uuid, {bool detailed = false}) → Future< List< Map< >String, dynamic> > -
listPath(
String remotePath) → Future< Map< String, List< >Map< >String, dynamic> > -
Available on FilenClient, provided by the FilenPaths extension
List contents of a folder by path. -
log(
String msg) → void -
login(
String email, String password, {String twoFactorCode = "XXXXXX"}) → Future< Map< String, dynamic> > -
logWebDAV(
String msg) → void -
moveByPath(
String sourcePath, String destPath) → Future< void> -
Available on FilenClient, provided by the FilenPaths extension
Move a file or folder by path. -
moveItem(
String uuid, String destUuid, String type) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
printTree(
String path, void printLine(String msg), {int maxDepth = 3}) → Future< void> -
renameByPath(
String remotePath, String newName) → Future< void> -
Available on FilenClient, provided by the FilenPaths extension
Rename a file or folder by path. -
renameItem(
String uuid, String newName, String type) → Future< void> -
resolvePath(
String path) → Future< Map< String, dynamic> > -
restoreItem(
String uuid, String type) → Future< void> -
search(
String query, {bool detailed = false}) → Future< Map< String, List< >Map< >String, dynamic> > -
setAuth(
Map< String, dynamic> c) → void -
shouldIncludeFile(
String fileName, List< String> include, List<String> exclude) → bool -
toString(
) → String -
A string representation of this object.
inherited
-
trashByPath(
String remotePath) → Future< void> -
Available on FilenClient, provided by the FilenPaths extension
Delete a file or folder by path (move to trash). -
trashItem(
String uuid, String type) → Future< void> -
upload(
List< String> sources, String targetPath, {required bool recursive, required String onConflict, required bool preserveTimestamps, required List<String> include, required List<String> exclude, required String batchId, Map<String, dynamic> ? initialBatchState, required Future<void> saveStateCallback(Map<String, dynamic> ), dynamic onFileProgress(String, int, int, int, int)?, int maxWorkers = kDefaultFileConcurrency}) → Future<void> -
uploadBytes(
Uint8List data, String fileName, String parentUuid, {int maxConcurrentChunks = kDefaultUploadConcurrency, dynamic onProgress(int, int)?}) → Future< void> -
uploadFile(
File file, String parent, {String? creationTime, String? modificationTime}) → Future< void> -
uploadFileBytes(
Uint8List bytes, String remotePath, {String? mimeType}) → Future< Map< String, String> > -
Available on FilenClient, provided by the FilenPaths extension
Upload raw bytes as a file to a remote path. -
uploadFileChunked(
File file, String parent, {String? fileUuid, String? creationTime, String? modificationTime, String? resumeUploadKey, int resumeFromChunk = 0, Set< int> ? completedChunks, String? fileKey, int maxConcurrentChunks = kDefaultUploadConcurrency, dynamic onProgress(int, int, int, int)?, dynamic onUploadStart(String, String, String)?, void onChunksCompleted(Set<int> )?}) → Future<Map< String, String> > -
uploadToPath(
File localFile, String remotePath, {bool preserveTimestamps = false}) → Future< Map< String, String> > -
Available on FilenClient, provided by the FilenPaths extension
Upload a local file to a remote path. -
verifyUploadMetadata(
String fileUuid, File originalFile) → Future< bool>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited