Returns a reference to a Directory that exists as a child of this directory and has the specified basename.
Directory
basename
@override Directory childDirectory(String basename) => fs.directory(p.join(path, basename));